Package: MerfishData
Title: Collection of public MERFISH datasets
Version: 1.12.0
Authors@R: 
    c(person("Ludwig", "Geistlinger", 
             role = c("aut", "cre"),
             email = "ludwig_geistlinger@hms.harvard.edu", 
             comment = c(ORCID = "0000-0002-2495-5464")),
      person("Tyrone", "Lee", role = "ctb"),
      person("Helena", "Crowell", role = "ctb",
             comment = c(ORCID = "0000-0002-4801-1767")), 
      person("Daniela", "Corbetta", role = "ctb"), 
      person("Jeffrey", "Moffitt", role = "aut"),
      person("Robert", "Gentleman", role = "aut"))
Description: MerfishData is an ExperimentHub package that serves publicly available
    datasets obtained with Multiplexed Error-Robust Fluorescence in situ Hybridization
    (MERFISH). MERFISH is a massively multiplexed single-molecule imaging technology
    capable of simultaneously measuring the copy number and spatial distribution
    of hundreds to tens of thousands of RNA species in individual cells. The scope
    of the package is to provide MERFISH data for benchmarking and analysis.
License: Artistic-2.0
VignetteBuilder: knitr
URL: https://github.com/ccb-hms/MerfishData
BugReports: https://github.com/ccb-hms/MerfishData/issues
Depends: R (>= 4.2.0), EBImage, SpatialExperiment
Imports: grDevices, AnnotationHub, BumpyMatrix, ExperimentHub,
        S4Vectors, SingleCellExperiment, SummarizedExperiment,
        HDF5Array
Suggests: grid, ggplot2, ggpubr, knitr, rmarkdown, scater, scattermore,
        terra, testthat, BiocStyle, DropletUtils
biocViews: ExperimentHub, ExpressionData, HighThroughputImagingData,
        Mus_musculus_Data, SingleCellData, SpatialData
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
git_url: https://git.bioconductor.org/packages/MerfishData
git_branch: RELEASE_3_22
git_last_commit: 42395d2
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-11-04
NeedsCompilation: no
Packaged: 2025-11-04 16:37:53 UTC; biocbuild
Author: Ludwig Geistlinger [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-2495-5464>),
  Tyrone Lee [ctb],
  Helena Crowell [ctb] (ORCID: <https://orcid.org/0000-0002-4801-1767>),
  Daniela Corbetta [ctb],
  Jeffrey Moffitt [aut],
  Robert Gentleman [aut]
Maintainer: Ludwig Geistlinger <ludwig_geistlinger@hms.harvard.edu>
