# A script to make the metadata.csv file located in inst/extdata of the package.
# See ?AnnotationHubData::makeAnnotationHubMetadata for a description of the 
# metadata.csv file, expected fields and data types. This 
# AnnotationHubData::makeAnnotationHubMetadata() function can be used to 
# validate the metadata.csv file before submitting the package.
